@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: psqueues
-version: 0.2.2.0
-id: psqueues-0.2.2.0-1c442d35f7d41befefb8cfb402624ddd
-key: psque_Eu4cvucK9D300LguHeaq9c
+version: 0.2.2.1
+id: psqueues-0.2.2.1-7824de609dc312a467c2b75622b6db3f
+key: psque_AvLcbKUIB1yCm8wZoS0YR7
 license: BSD3
 maintainer: Jasper Van der Jeugt <jaspervdj@gmail.com>
 synopsis: Pure priority search queues
@@ -56,10 +56,10 @@ exposed-modules:
 hidden-modules: Data.BitUtil Data.HashPSQ.Internal
                 Data.IntPSQ.Internal Data.OrdPSQ.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/psqueues-0.2.2.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/psqueues-0.2.2.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/psqueues-0.2.2.0
-hs-libraries: HSpsqueues-0.2.2.0-Eu4cvucK9D300LguHeaq9c
+import-dirs: /usr/lib/ghc-7.10.3/site-local/psqueues-0.2.2.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/psqueues-0.2.2.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/psqueues-0.2.2.1
+hs-libraries: HSpsqueues-0.2.2.1-AvLcbKUIB1yCm8wZoS0YR7
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
